@@ -199,7 +199,7 @@ rstan_config <- function(pkgdir = ".") {
     # Stanc3 gives 'auto' return type for standalone functions, which
     #   causes errors with Rcpp::export, so need to replace the auto
     #   return with the plain type from the main definition
-    if(utils::packageVersion('rstan') >= "2.26") {
+    if(utils::packageVersion('rstan') >= "2.26" && utils::packageVersion('StanHeaders') < "2.33") {
       # Extract line numbers of functions to be exported
       decl_lines = grep("// \\[\\[Rcpp::export]]",cpp_lines) + 1
 
@@ -214,11 +214,15 @@ rstan_config <- function(pkgdir = ".") {
     eigen_incl <- ifelse(utils::packageVersion('StanHeaders') >= "2.31",
                          "#include <stan/math/prim/fun/Eigen.hpp>",
                          "#include <stan/math/prim/mat/fun/Eigen.hpp>")
+    pkgname <- tryCatch(unname(read.dcf("DESCRIPTION", "Package")[1, 1]),
+                        warning = function(w) {
+                          basename(pkgdir)
+                        })
     cat("#include <exporter.h>",
         eigen_incl,
         "#include <stan/math/prim/meta.hpp>",
         file = file.path(pkgdir, "src",
-                         paste(basename(pkgdir), "types.h", sep = "_")),
+                         paste(pkgname, "types.h", sep = "_")),
         sep = "\n")
 
   } else { # actual Stan model
@@ -236,6 +240,11 @@ rstan_config <- function(pkgdir = ".") {
     } else {
       cppcode <- c("#include <rstan/rstaninc.hpp>", cppcode)
     }
+    rng_type <- ifelse(utils::packageVersion('StanHeaders') >= "2.34",
+                       "stan::rng_t", "boost::ecuyer1988")
+    if (utils::packageVersion('StanHeaders') >= "2.34") {
+      cppcode <- gsub("boost::ecuyer1988", "stan::rng_t", cppcode, fixed = TRUE)
+    }
     # Stan header file
     hdr_name <- .stan_prefix(model_name, ".h")
     # get license file (if any)
@@ -275,7 +284,7 @@ rstan_config <- function(pkgdir = ".") {
                                   header = paste0('#include "', hdr_name, '"'),
                                   module = paste0("stan_fit4",
                                                   model_name, "_mod"),
-                                  CppClass = "rstan::stan_fit<stan_model, boost::random::ecuyer1988> ",
+                                  CppClass = paste0("rstan::stan_fit<stan_model, ", rng_type, "> "),
                                   Rfile = FALSE)
               )
     })
