@@ -2,7 +2,13 @@ context("default methods")
 set.seed(1111)
 x <- matrix(rnorm(150), 50, 3)
 y <- rnorm(ncol(x))
-
+lw <- matrix(rnorm(150), 50, 3)
+lw <- sweep(
+  lw,
+  MARGIN = 2,
+  STATS = apply(lw, 2, function(col) log(sum(exp(col)))),
+  check.margin = FALSE
+)
 
 test_that("posterior_interval.default hasn't changed", {
   expect_equal_to_reference(
@@ -29,17 +35,33 @@ test_that("prior_summary.default works", {
   expect_null(prior_summary(list(abc = "prior_info")))
 })
 test_that("loo_pit.default works", {
-  lw <- matrix(rnorm(150), 50, 3)
   expect_equal_to_reference(
     loo_pit(x, y, lw),
     "loo_pit.RDS"
   )
 })
+test_that("loo_pit-default works for discrete data", {
+  set.seed(1111)
+  expect_equal_to_reference(
+    loo_pit(round(x), round(y), lw),
+    "loo_pit_discrete.RDS"
+  )
+})
+test_that("bayes_R2.default hasn't changed", {
+  expect_equal_to_reference(
+    bayes_R2(x, y),
+    "bayes_R2.RDS"
+  )
+})
 
 test_that("default methods throw correct errors", {
   expect_error(posterior_interval(1:10), "should be a matrix")
   expect_error(predictive_interval(1:10), "should be a matrix")
   expect_error(predictive_error(1:10, 1:10), "should be a matrix")
+  expect_error(bayes_R2(1:10, 1:10), "should be a matrix")
+  expect_error(bayes_R2(cbind(1:10, 1:10), 1:9),
+               "ncol(object) == length(y) is not TRUE",
+               fixed = TRUE)
 })
 
 
@@ -73,4 +95,3 @@ test_that(".pred_errors throws errors", {
                fixed = TRUE)
 })
 
-
